@@ -4,7 +4,7 @@
  *      Copyright (C) 1996
  *          Thomas Sailer (sailer@ife.ee.ethz.ch, hb9jnx@hb9w.che.eu)
  *
- *      Copyright (C) 2012-2019
+ *      Copyright (C) 2012-2020
  *          Elias Oenal    (multimon-ng@eliasoenal.com)
  *
  *      This program is free software; you can redistribute it and/or modify
@@ -93,6 +93,8 @@ static bool is_startline = true;
 static int timestamp = 0;
 static char *label = NULL;
 
+extern bool fms_justhex;
+
 extern int pocsag_mode;
 extern int pocsag_invert_input;
 extern int pocsag_error_correction;
@@ -272,7 +274,7 @@ static void input_sound(unsigned int sample_rate, unsigned int overlap,
     
     /* Create the recording stream */
     if (!(s = pa_simple_new(NULL, "multimon-ng", PA_STREAM_RECORD, NULL, "record", &ss, NULL, NULL, &error))) {
-        fprintf(stderr, __FILE__": pa_simple_new() failed: %s\n", pa_strerror(error));
+        fprintf(stderr, "unixinput.c: pa_simple_new() failed: %s\n", pa_strerror(error));
         exit(4);
     }
     
@@ -578,6 +580,7 @@ static const char usage_str[] = "\n"
         "  -m         : Mute SoX warnings\n"
         "  -r         : Call SoX in repeatable mode (e.g. fixed random seed for dithering)\n"
         "  -n         : Don't flush stdout, increases performance.\n"
+        "  -j         : FMS: Just output hex data and CRC, no parsing.\n"
         "  -e         : POCSAG: Hide empty messages.\n"
         "  -u         : POCSAG: Heuristically prune unlikely decodes.\n"
         "  -i         : POCSAG: Inverts the input samples. Try this if decoding fails.\n"
@@ -618,7 +621,7 @@ int main(int argc, char *argv[])
         {0, 0, 0, 0}
       };
 
-    while ((c = getopt_long(argc, argv, "t:a:s:v:b:f:g:d:o:cqhAmrxynipeuC:", long_options, NULL)) != EOF) {
+    while ((c = getopt_long(argc, argv, "t:a:s:v:f:b:C:o:d:g:cqhAmrnjeuipxy", long_options, NULL)) != EOF) {
         switch (c) {
         case 'h':
         case '?':
@@ -668,6 +671,10 @@ int main(int argc, char *argv[])
         case 'm':
             mute_sox = 1;
             break;
+
+        case 'j':
+            fms_justhex = true;
+            break;
             
         case 'r':
             repeatable_sox = 1;
@@ -794,9 +801,9 @@ intypefound:
 
     if ( !quietflg )
     { // pay heed to the quietflg
-    fprintf(stderr, "multimon-ng 1.1.8\n"
+    fprintf(stderr, "multimon-ng 1.1.9\n"
         "  (C) 1996/1997 by Tom Sailer HB9JNX/AE4WA\n"
-        "  (C) 2012-2019 by Elias Oenal\n"
+        "  (C) 2012-2020 by Elias Oenal\n"
         "Available demodulators:");
     for (i = 0; (unsigned int) i < NUMDEMOD; i++) {
         fprintf(stderr, " %s", dem[i]->name);
